# Getting start with Plaso

Getting started with Plaso can be challenging at first. This page describes some of the steps we recommend taking.

## I just want to run plaso log2timeline

If you just want to run plaso we recommend to use a [packaged release](Releases-and-roadmap.md) unless you are the adventurous type.

To get started have a look at the [User Guide](Users-Guide.md).

If you have questions, suggestions and want to discuss them join the general discussions mailing list: [log2timeline-discuss](https://groups.google.com/forum/#!forum/log2timeline-discuss)

## I want to develop Plaso 

There are various ways to develop with plaso. We expect the more common use case that you would like to extend plaso by adding a parser or plugin or equivalent.

For this you'll need to use a [development release](Releases-and-roadmap.md).

Get a github and gmail account and enable 2-factor authentication.

To get started have a look at the [Developers guide](../developer/Developers-Guide.md).

Last but not least we also recommend joining the development mailing list: [log2timeline-dev](https://groups.google.com/forum/#!forum/log2timeline-dev)

### But I don't know how to use git

* [Got 15 minutes and want to learn Git?](https://try.github.io/levels/1/challenges/1)

### But I don't know how to program in Python

**TODO add links**